@@ -17,9 +17,10 @@ package Pod::Loom;
 # ABSTRACT: Weave pseudo-POD into real POD
 #---------------------------------------------------------------------
 
-our $VERSION = '0.02';
-
 use 5.008;
+our $VERSION = '0.03';
+# This file is part of Pod-Loom 0.03 (March 6, 2010)
+
 use Moose;
 use Carp qw(croak);
 use PPI ();
@@ -86,6 +87,7 @@ sub weave
 
   my $newPod = $template->weave(\$sourcePod, $filename);
   $newPod =~ s/(?:\s*\n=cut)*\s*\z/\n\n=cut\n/; # ensure it ends with =cut
+  $newPod = '' if $newPod =~ /^\s*=cut$/;       # if it's blank, ignore it
 
   # Plug the new POD back into the code:
 
@@ -140,9 +142,9 @@ Pod::Loom - Weave pseudo-POD into real POD
 
 =head1 VERSION
 
-This document describes version 0.02 of
-Pod::Loom, released October 20, 2009
-as part of Pod-Loom version 0.02.
+This document describes version 0.03 of
+Pod::Loom, released March 6, 2010
+as part of Pod-Loom version 0.03.
 
 =head1 WARNING
 
@@ -271,10 +273,10 @@ No bugs have been reported.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  S<< C<< <perl AT cjmweb.net> >> >>
+Christopher J. Madsen  C<< <perlATcjmweb.net> >>
 
 Please report any bugs or feature requests to
-S<< C<< <bug-Pod-Loom AT rt.cpan.org> >> >>,
+C<< <bug-Pod-LoomATrt.cpan.org> >>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Pod-Loom>
 
@@ -283,7 +285,7 @@ L<< http://github.com/madsen/pod-loom >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Christopher J. Madsen.
+This software is copyright (c) 2010 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
